"""Defines the top-level API for the actuator package."""

__version__ = "0.0.17"

from .rust.bindings import (
    PyRobstrideMotorControlParams as RobstrideMotorControlParams,
    PyRobstrideMotorFeedback as RobstrideMotorFeedback,
    PyRobstrideMotors as RobstrideMotors,
    PyRobstrideMotorsSupervisor as RobstrideMotorsSupervisor,
)



# This file is automatically generated by pyo3_stub_gen
# ruff: noqa: E501, F401

import typing

class PyRobstrideMotorControlParams:
    position: float
    velocity: float
    kp: float
    kd: float
    torque: float
    def __new__(cls,position:float, velocity:float, kp:float, kd:float, torque:float): ...
    def __repr__(self) -> str:
        ...


class PyRobstrideMotorFeedback:
    can_id: int
    position: float
    velocity: float
    torque: float
    mode: str
    faults: int
    def __repr__(self) -> str:
        ...


class PyRobstrideMotors:
    def __new__(cls,port_name,motor_infos,verbose = ...): ...
    def send_get_mode(self) -> dict[int, str]:
        ...

    def send_set_zero(self, motor_ids:typing.Optional[typing.Sequence[int]]) -> None:
        ...

    def send_resets(self) -> None:
        ...

    def send_starts(self) -> None:
        ...

    def send_motor_controls(self, motor_controls:typing.Mapping[int, PyRobstrideMotorControlParams], serial:bool) -> dict[int, PyRobstrideMotorFeedback]:
        ...

    def __repr__(self) -> str:
        ...


class PyRobstrideMotorsSupervisor:
    total_commands: int
    actual_update_rate: float
    serial: bool
    def __new__(cls,port_name,motor_infos,verbose = ...,target_update_rate = ...): ...
    def set_position(self, motor_id:int, position:float) -> float:
        ...

    def get_position(self, motor_id:int) -> float:
        ...

    def set_velocity(self, motor_id:int, velocity:float) -> float:
        ...

    def get_velocity(self, motor_id:int) -> float:
        ...

    def set_kp(self, motor_id:int, kp:float) -> float:
        ...

    def get_kp(self, motor_id:int) -> float:
        ...

    def set_kd(self, motor_id:int, kd:float) -> float:
        ...

    def get_kd(self, motor_id:int) -> float:
        ...

    def set_torque(self, motor_id:int, torque:float) -> float:
        ...

    def get_torque(self, motor_id:int) -> float:
        ...

    def add_motor_to_zero(self, motor_id:int) -> None:
        ...

    def get_latest_feedback(self) -> dict[int, PyRobstrideMotorFeedback]:
        ...

    def toggle_pause(self) -> None:
        ...

    def stop(self) -> None:
        ...

    def __repr__(self) -> str:
        ...

    def set_params(self, motor_id:int, params:PyRobstrideMotorControlParams) -> None:
        ...

    def failed_commands_for(self, motor_id:int) -> int:
        ...

    def reset_command_counters(self) -> None:
        ...

    def max_update_rate(self, rate:float) -> None:
        ...

    def toggle_serial(self) -> bool:
        ...





# mypy: disable-error-code="import-untyped"
#!/usr/bin/env python
"""Setup script for the project."""

import glob
import re

from setuptools import setup
from setuptools_rust import Binding, RustExtension

with open("README.md", "r", encoding="utf-8") as f:
    long_description: str = f.read()


with open("actuator/requirements.txt", "r", encoding="utf-8") as f:
    requirements: list[str] = f.read().splitlines()


with open("actuator/requirements-dev.txt", "r", encoding="utf-8") as f:
    requirements_dev: list[str] = f.read().splitlines()


with open("actuator/__init__.py", "r", encoding="utf-8") as fh:
    version_re = re.search(r"^__version__ = \"([^\"]*)\"", fh.read(), re.MULTILINE)
assert version_re is not None, "Could not find version in actuator/__init__.py"
version: str = version_re.group(1)

package_data = [f"actuator/{name}" for name in ("py.typed", "requirements.txt", "requirements-dev.txt")]
package_data.append("Cargo.toml")
for ext in ("pyi", "rs", "toml", "so"):
    package_data.extend(glob.iglob(f"actuator/**/*.{ext}", recursive=True))


setup(
    name="actuator",
    version=version,
    description="Python interface for controlling various robotic actuators",
    author="Benjamin Bolte",
    url="https://github.com/kscalelabs/actuator",
    rust_extensions=[
        RustExtension(
            target="actuator.rust.bindings",
            path="actuator/rust/bindings/Cargo.toml",
            binding=Binding.PyO3,
        ),
    ],
    setup_requires=["setuptools-rust"],
    zip_safe=False,
    long_description=long_description,
    long_description_content_type="text/markdown",
    python_requires=">=3.11",
    install_requires=requirements,
    extras_require={"dev": requirements_dev},
    include_package_data=True,
    package_data={"actuator": package_data},
    packages=["actuator"],
)
